/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global document, tizen, window, console*/

/**
 * Main application module.
 * Provides a namespace for other application modules.
 * Handles application life cycle.
 *
 * @module app
 * @namespace app
 */

// make sure that "app" namespace is created
window.app = window.app || {};

(function application(app) {

    'use strict';

    /**
     * Handles tizenhwkey event.
     * Closes application or MIME selection popup if opened.
     *
     * @memberof app
     * @private
     * @param {Event} e
     */
    function onHwKeyEvent(e) {
        if (e.keyName === 'back') {
            if (!app.view.isMimePopupOpen()) {
                try {
                    tizen.application.getCurrentApplication().exit();
                } catch (error) {
                    console.error(error);
                }
            } else {
                app.view.hideMimePopup();
            }
        }
    }

    /**
     * Binds listener for hardware key press.
     *
     * @memberof app
     * @private
     */
    function bindEvents() {
        document.addEventListener('tizenhwkey', onHwKeyEvent);
    }

    /**
     * Initializes application.
     *
     * @memberof app
     * @private
     */
    function init() {
        bindEvents();
        app.view.init();
    }

    window.addEventListener('load', init);

}(window.app));
